// ************************************************************
// simple.C
// 
// An example to run PYTHIA and Quick Siumlator, and create
// histograms of visible energy and charged track multiplicity.
//  
//   void Analize(Int_t ev) ;  Fill histograms
//   void InitHist()        ;  Define histograms
//   Int_t simple()         ;  Main   
// 
// ************************************************************

Int_t   maxevt=200;            // Number of events to generate
Char_t *outputfile="jsf.root";   // Output file name
Float_t fEcm=300.0;              // Center of mass energy
  
TFile        *file;
JSFQuickSim  *sim;
TCanvas      *c1;
TH1F         *hEvis, *hNtrack;

// *****************************************
// Analize event
// *****************************************
void Analize(Int_t ev)
{
  JSFQuickSimBuf *buf=(JSFQuickSimBuf*)sim->EventBuf();
  Int_t nt=buf->GetNtracks();
  TClonesArray *tracks=buf->GetTracks();
  // Loop over all tracks.
  Int_t nc=0;
  Float_t evis=0.0;
  for(Int_t i=0;i<nt;i++){
    JSFLTKCLTrack *t=(JSFLTKCLTrack*)tracks->UncheckedAt(i);
    evis += t->GetE();
    if( t->GetCharge() != 0 ) nc++ ;
  }
  hEvis->Fill(evis);
  hNtrack->Fill((Float_t) nc);

  // Display Visible energy distribution when event no. > 10 
  if( ev > 10 ) {
	file->cd();
	hEvis->Draw();
	c1->Update();
  }
	
}
// *****************************************
// Initialize histogram
// *****************************************
void InitHist()
{
  file->cd();
  c1     = new TCanvas("c1","Canvas 1",100, 100, 800, 800);
  hEvis  = new TH1F("hEvis","Visible energy",100,0.0, 500.0);
  hNtrack= new TH1F("hNtrack","Charged multiplicity",50,0.0,100.0);
}

//*************************************************
//* Main part to generate qqbar event
//*************************************************
int simple()
{
  file = new TFile(outputfile,"RECREATE");  // Output file

  jsf   = new JSFSteer();
  full  = new JSFLCFULL();
  py    = new PythiaGenerator();
  sim   = new JSFQuickSim();
  
  py->SetEcm(fEcm);             // Center of mass energy (GeV)
  InitHist();
  jsf->Initialize();

  jsf->BeginRun(1);             // Set run number to 1(Dummy)
  for(Int_t ev=1;ev<=maxevt;ev++){
    if( !jsf->Process(ev) ) break;
    Analize(ev);                
    jsf->FillTree();
    jsf->Clear();
  }

  jsf->Terminate();
  file->Write();
}
